@@ -26,7 +26,8 @@ def ifpercent(part, whole, percent):
         try:
             return pycent.percentage(part, whole)
         except ZeroDivisionError:
-            sys.exit()
+            return 0
+            # sys.exit()
     else:
         return part
 
@@ -122,10 +123,9 @@ Resource type: Kind of resource eg. Barbora CPU, Karolina GPU,...
 """ % (TABLE_ME_TITLE, TABLE_ME_AS_PI_TITLE),
                                      formatter_class=argparse.RawTextHelpFormatter)
     parser.add_argument('-p', '--percent', action='store_true',
-                        help="""
-show values in percentage. Projects with unlimited resources are not displayed""")
-    parser.add_argument('-u', '--unit', action='store', help='unit', default='real',
-                        choices=['perc', 'real', 'both'])
+                        help="""show values in percentage. Projects with unlimited resources are not displayed""")
+    # parser.add_argument('-u', '--unit', action='store', help='unit', default='real',
+    #                     choices=['perc', 'real', 'both'])
     parser.add_argument('-a', '--all', action='store_true',
                         help="""Show all resources include inactive and future ones.""")
     arguments = parser.parse_args()
@@ -140,7 +140,7 @@ Suggested paths:
     username = getpass.getuser().strip()
     # username = 'kvi0029'
 
-    if arguments.all != None:
+    if arguments.all != False:
         jsonout = jsondata(('%s/it4ifree/%s' % (API_URL, username)), {'it4ifreetoken': IT4IFREETOKEN, 'all': 'yes'})
     else:
         jsonout = jsondata(('%s/it4ifree/%s' % (API_URL, username)), {'it4ifreetoken': IT4IFREETOKEN})
