@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 """
-Shows user filesystem usage of IT4I cluster storage systems
+Shows filesystem usage of IT4I cluster storage systems
 """
 import argparse
 import getpass
@@ -38,13 +38,8 @@ def main():
     """
 
     parser = argparse.ArgumentParser(description="""
-The command shows user filesystem usage of IT4I cluster storage systems""")
-    parser.add_argument('-c', '--cluster',
-                        default='all',
-                        action='store',
-                        choices=['all', 'anselm', 'salomon', 'barbora'],
-                        help="select cluster")
-    arguments = parser.parse_args()
+The command shows filesystem usage of IT4I cluster storage systems""")
+    parser.parse_args()
 
     if IT4IFREETOKEN is None:
         LOGGER.error("""Missing or unset configuration option: %s
@@ -56,11 +51,10 @@ Suggested paths:
     username = getpass.getuser().strip()
     remote = ('%s/fs-usage' % (API_URL))
     data = {'login': username,
-            'it4ifreetoken' : IT4IFREETOKEN,
-            'cluster': arguments.cluster}
+            'it4ifreetoken' : IT4IFREETOKEN}
     jsonout = jsondata(remote, data)
 
-    table_header = ['Type',
+    table_header = ['Quota Type',
                     'Cluster / PID',
                     'File System',
                     'Space used',
